==> ValueAdd%20v1.02%20Source.zip: ValueAdd/Information.h <==
// rSDK demonstration release - www.aquadasoft.com
// Jamie McLaughlin and Jean Villy Edberg

// Send any queries or bug reports to support@aquadasoft.com

// --------------------
// Object information
// --------------------

// Basic object details
#define	ObjectName			"Value-Add Object"
#define	ObjectAuthor		"Gareth Ben Martin of Dynamic Arcade"
#define	ObjectCopyright		"Copyright  2008 Dynamic Arcade"
#define	ObjectComment		"Unlimited Alterable Values for all objects"
#define	ObjectURL			"http://www.dynamicarcade.co.uk"
#define	ObjectHelp			"Help\\Value Add\\Value Add.html"

// If you register your object with Clickteam, change this to the ID you were given
#define ObjectRegID			REGID_PRIVATE

// Change N,O,N,E to 4 unique characters (MMF currently still uses this to keep track)
#define	IDENTIFIER MAKEID(D,A,V,A)

// Version 1.2
#define	VERSION 120

// --------------------
// Version information
// --------------------

// PRODUCT_VERSION_TGF or PRODUCT_VERSION_DEVELOPER
#define ForVersion PRODUCT_VERSION_STANDARD

// Set this to the latest MMF build out when you build the object
#define	MinimumBuild 244

// --------------------
// Beta information
// --------------------

// #define BETA
// #define POPUP_ON_DROP
// #define POPUP_ON_EXE
// #define POPUP_ON_BUILD
// #define POPUP_MESSAGE "This is a beta extension- use with caution!"

// --------------------
// Handling priority
// --------------------
// If this extension will handle windows messages, specify the priority
// of the handling procedure, 0 = low and 255 = very high

#define	WINDOWPROC_PRIORITY 100

==> ValueAdd%20v1.09%20Source.zip: ValueAdd/Information.h <==
// rSDK demonstration release - www.aquadasoft.com
// Jamie McLaughlin and Jean Villy Edberg

// Send any queries or bug reports to support@aquadasoft.com

// --------------------
// Object information
// --------------------

// Basic object details
#define	ObjectName			"Value-Add Object"
#define	ObjectAuthor		"Gareth Ben Martin of Dynamic Arcade"
#define	ObjectCopyright		"Copyright  2008-2010 Dynamic Arcade"
#define	ObjectComment		"Unlimited Alterable Values for all objects"
#define	ObjectURL			"http://www.dynamicarcade.co.uk"
#define	ObjectHelp			"Help\\ValueAdd\\ValueAdd.html"

// If you register your object with Clickteam, change this to the ID you were given
#define ObjectRegID			REGID_PRIVATE

// Change N,O,N,E to 4 unique characters (MMF currently still uses this to keep track)
#define	IDENTIFIER MAKEID(D,A,V,A)

// Version 1.09.0
#define	VERSION 190

#define	SAVEDATAVERSION_MINSUPPORTED 1
#define	SAVEDATAVERSION_STRINGSADDED 2
#define	SAVEDATAVERSION 2

// --------------------
// Version information
// --------------------

// PRODUCT_VERSION_TGF or PRODUCT_VERSION_DEVELOPER
#define ForVersion PRODUCT_VERSION_STANDARD

// Set this to the latest MMF build out when you build the object
#define	MinimumBuild 244

// --------------------
// Beta information
// --------------------

// #define BETA
// #define POPUP_ON_DROP
// #define POPUP_ON_EXE
// #define POPUP_ON_BUILD
// #define POPUP_MESSAGE "This is a beta extension- use with caution!"

// --------------------
// Handling priority
// --------------------
// If this extension will handle windows messages, specify the priority
// of the handling procedure, 0 = low and 255 = very high

#define	WINDOWPROC_PRIORITY 100
